import React from 'react';
import { PropsWithMetadata, noop, ComponentMetadata } from '@highlight-ui/utils-commons';
export declare type ToggleProps = PropsWithMetadata<{
    /**
     * Determines whether the Toggle is currently switched on or off
     */
    checked: boolean;
    /**
     * Callback invoked when the user switches the Toggle on or off
     */
    onToggle: typeof noop;
    /**
     * Determines whether the Toggle should render in a disabled state
     */
    disabled?: boolean;
    /**
     * An optional unique ID to link the form components.
     * If not supplied, a unique ID will be generated internally.
     */
    id?: string;
    /**
     * Allows providing a custom class name to the DIV element that surrounds the text
     */
    className?: string;
    /**
     * Optional title to be rendered beside the toggle.
     */
    title?: string;
    /**
     * Optional metadata which will be mapped as HTML data attributes to the title.
     */
    titleMetadata?: ComponentMetadata;
    /**
     * Optional sub-title to be rendered underneath the title.
     * Cannot be rendered without a title.
     */
    subTitle?: string;
}>;
declare const Toggle: React.ForwardRefExoticComponent<{
    /**
     * Determines whether the Toggle is currently switched on or off
     */
    checked: boolean;
    /**
     * Callback invoked when the user switches the Toggle on or off
     */
    onToggle: typeof noop;
    /**
     * Determines whether the Toggle should render in a disabled state
     */
    disabled?: boolean | undefined;
    /**
     * An optional unique ID to link the form components.
     * If not supplied, a unique ID will be generated internally.
     */
    id?: string | undefined;
    /**
     * Allows providing a custom class name to the DIV element that surrounds the text
     */
    className?: string | undefined;
    /**
     * Optional title to be rendered beside the toggle.
     */
    title?: string | undefined;
    /**
     * Optional metadata which will be mapped as HTML data attributes to the title.
     */
    titleMetadata?: ComponentMetadata | undefined;
    /**
     * Optional sub-title to be rendered underneath the title.
     * Cannot be rendered without a title.
     */
    subTitle?: string | undefined;
} & {
    metadata?: ComponentMetadata | undefined;
} & React.RefAttributes<HTMLLabelElement>>;
export default Toggle;
